/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (C) 2014 Google, Inc
 *
 * Device Tree binding constants for the Maxim 77802 PMIC regulators
 */

#ifndef _DT_BINDINGS_REGULATOR_MAXIM_MAX77802_H
#define _DT_BINDINGS_REGULATOR_MAXIM_MAX77802_H

/* Regulator operating modes */
#define MAX77802_OPMODE_LP	1
#define MAX77802_OPMODE_NORMAL	3

#endif /* _DT_BINDINGS_REGULATOR_MAXIM_MAX77802_H */
