/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Marvell XOR platform device data definition file.
 */

#ifndef __DMA_MV_XOR_H
#define __DMA_MV_XOR_H

#include <linux/dmaengine.h>
#include <linux/mbus.h>

#define MV_XOR_NAME	"mv_xor"

struct mv_xor_channel_data {
	dma_cap_mask_t			cap_mask;
};

struct mv_xor_platform_data {
	struct mv_xor_channel_data    *channels;
};

#endif
