/* SPDX-License-Identifier: GPL-2.0+ */

#ifndef __DT_BINDINGS_CLOCK_BCM6328_H
#define __DT_BINDINGS_CLOCK_BCM6328_H

#define BCM6328_CLK_PHYMIPS	0
#define BCM6328_CLK_ADSL_QPROC	1
#define BCM6328_CLK_ADSL_AFE	2
#define BCM6328_CLK_ADSL	3
#define BCM6328_CLK_MIPS	4
#define BCM6328_CLK_SAR		5
#define BCM6328_CLK_PCM		6
#define BCM6328_CLK_USBD	7
#define BCM6328_CLK_USBH	8
#define BCM6328_CLK_HSSPI	9
#define BCM6328_CLK_PCIE	10
#define BCM6328_CLK_ROBOSW	11

#endif /* __DT_BINDINGS_CLOCK_BCM6328_H */
