/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright 2010 Yong Shen <yong.shen@linaro.org>
 */

#ifndef __LINUX_MFD_MC13892_H
#define __LINUX_MFD_MC13892_H

#include <linux/mfd/mc13xxx.h>

#define MC13892_SW1		0
#define MC13892_SW2		1
#define MC13892_SW3		2
#define MC13892_SW4		3
#define MC13892_SWBST	4
#define MC13892_VIOHI	5
#define MC13892_VPLL	6
#define MC13892_VDIG	7
#define MC13892_VSD	8
#define MC13892_VUSB2	9
#define MC13892_VVIDEO	10
#define MC13892_VAUDIO	11
#define MC13892_VCAM	12
#define MC13892_VGEN1	13
#define MC13892_VGEN2	14
#define MC13892_VGEN3	15
#define MC13892_VUSB	16
#define MC13892_GPO1	17
#define MC13892_GPO2	18
#define MC13892_GPO3	19
#define MC13892_GPO4	20
#define MC13892_PWGT1SPI	21
#define MC13892_PWGT2SPI	22
#define MC13892_VCOINCELL	23

#endif
