/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */

#ifndef _DT_BINDINGS_CLK_MT6735_APMIXEDSYS_H
#define _DT_BINDINGS_CLK_MT6735_APMIXEDSYS_H

#define CLK_APMIXED_ARMPLL		0
#define CLK_APMIXED_MAINPLL		1
#define CLK_APMIXED_UNIVPLL		2
#define CLK_APMIXED_MMPLL		3
#define CLK_APMIXED_MSDCPLL		4
#define CLK_APMIXED_VENCPLL		5
#define CLK_APMIXED_TVDPLL		6
#define CLK_APMIXED_APLL1		7
#define CLK_APMIXED_APLL2		8

#endif
