autoconfig := include/config/auto.conf

deps_config := \
	Kconfig \
	scripts/Kconfig.include \
	init/Kconfig \
	kernel/irq/Kconfig \
	kernel/time/Kconfig \
	kernel/bpf/Kconfig \
	kernel/bpf/preload/Kconfig \
	kernel/Kconfig.preempt \
	kernel/rcu/Kconfig \
	usr/Kconfig \
	kernel/Kconfig.kexec \
	kernel/liveupdate/Kconfig \
	arch/Kconfig \
	arch/x86/Kconfig \
	arch/x86/xen/Kconfig \
	arch/x86/Kconfig.cpu \
	arch/x86/events/Kconfig \
	kernel/Kconfig.hz \
	kernel/livepatch/Kconfig \
	kernel/power/Kconfig \
	drivers/acpi/Kconfig \
	drivers/acpi/nfit/Kconfig \
	drivers/acpi/numa/Kconfig \
	drivers/acpi/apei/Kconfig \
	drivers/acpi/dptf/Kconfig \
	drivers/acpi/arm64/Kconfig \
	drivers/acpi/riscv/Kconfig \
	drivers/acpi/pmic/Kconfig \
	drivers/cpufreq/Kconfig \
	drivers/cpufreq/Kconfig.x86 \
	drivers/cpufreq/Kconfig.arm \
	drivers/cpufreq/Kconfig.powerpc \
	drivers/cpuidle/Kconfig \
	drivers/cpuidle/Kconfig.arm \
	drivers/cpuidle/Kconfig.mips \
	drivers/cpuidle/Kconfig.powerpc \
	drivers/cpuidle/Kconfig.riscv \
	drivers/idle/Kconfig \
	arch/x86/kvm/Kconfig \
	virt/kvm/Kconfig \
	arch/x86/Kconfig.cpufeatures \
	arch/x86/Kconfig.assembler \
	kernel/gcov/Kconfig \
	scripts/gcc-plugins/Kconfig \
	kernel/module/Kconfig \
	block/Kconfig \
	block/partitions/Kconfig \
	block/Kconfig.iosched \
	kernel/Kconfig.locks \
	kernel/Kconfig.freezer \
	fs/Kconfig.binfmt \
	mm/Kconfig \
	mm/damon/Kconfig \
	net/Kconfig \
	net/packet/Kconfig \
	net/psp/Kconfig \
	net/unix/Kconfig \
	net/tls/Kconfig \
	net/xfrm/Kconfig \
	net/iucv/Kconfig \
	net/smc/Kconfig \
	drivers/dibs/Kconfig \
	net/xdp/Kconfig \
	net/ipv4/Kconfig \
	net/ipv6/Kconfig \
	net/netlabel/Kconfig \
	net/mptcp/Kconfig \
	net/netfilter/Kconfig \
	net/netfilter/ipset/Kconfig \
	net/netfilter/ipvs/Kconfig \
	net/ipv4/netfilter/Kconfig \
	net/ipv6/netfilter/Kconfig \
	net/bridge/netfilter/Kconfig \
	net/sctp/Kconfig \
	net/rds/Kconfig \
	net/tipc/Kconfig \
	net/atm/Kconfig \
	net/l2tp/Kconfig \
	net/802/Kconfig \
	net/bridge/Kconfig \
	net/dsa/Kconfig \
	net/8021q/Kconfig \
	net/llc/Kconfig \
	net/appletalk/Kconfig \
	net/x25/Kconfig \
	net/lapb/Kconfig \
	net/phonet/Kconfig \
	net/6lowpan/Kconfig \
	net/ieee802154/Kconfig \
	net/ieee802154/6lowpan/Kconfig \
	net/mac802154/Kconfig \
	net/sched/Kconfig \
	net/dcb/Kconfig \
	net/dns_resolver/Kconfig \
	net/batman-adv/Kconfig \
	net/openvswitch/Kconfig \
	net/vmw_vsock/Kconfig \
	net/netlink/Kconfig \
	net/mpls/Kconfig \
	net/nsh/Kconfig \
	net/hsr/Kconfig \
	net/switchdev/Kconfig \
	net/l3mdev/Kconfig \
	net/qrtr/Kconfig \
	net/ncsi/Kconfig \
	net/ax25/Kconfig \
	drivers/net/hamradio/Kconfig \
	net/can/Kconfig \
	net/can/j1939/Kconfig \
	net/bluetooth/Kconfig \
	net/bluetooth/rfcomm/Kconfig \
	net/bluetooth/bnep/Kconfig \
	net/bluetooth/cmtp/Kconfig \
	net/bluetooth/hidp/Kconfig \
	drivers/bluetooth/Kconfig \
	net/rxrpc/Kconfig \
	net/kcm/Kconfig \
	net/strparser/Kconfig \
	net/mctp/Kconfig \
	net/wireless/Kconfig \
	net/mac80211/Kconfig \
	net/rfkill/Kconfig \
	net/9p/Kconfig \
	net/caif/Kconfig \
	net/ceph/Kconfig \
	net/nfc/Kconfig \
	net/nfc/nci/Kconfig \
	net/nfc/hci/Kconfig \
	drivers/nfc/Kconfig \
	drivers/nfc/fdp/Kconfig \
	drivers/nfc/pn544/Kconfig \
	drivers/nfc/pn533/Kconfig \
	drivers/nfc/microread/Kconfig \
	drivers/nfc/nfcmrvl/Kconfig \
	drivers/nfc/st21nfca/Kconfig \
	drivers/nfc/st-nci/Kconfig \
	drivers/nfc/nxp-nci/Kconfig \
	drivers/nfc/s3fwrn5/Kconfig \
	drivers/nfc/st95hf/Kconfig \
	net/psample/Kconfig \
	net/ife/Kconfig \
	drivers/Kconfig \
	drivers/amba/Kconfig \
	drivers/eisa/Kconfig \
	drivers/pci/Kconfig \
	drivers/pci/pcie/Kconfig \
	drivers/pci/hotplug/Kconfig \
	drivers/pci/controller/Kconfig \
	drivers/pci/controller/cadence/Kconfig \
	drivers/pci/controller/dwc/Kconfig \
	drivers/pci/controller/mobiveil/Kconfig \
	drivers/pci/controller/plda/Kconfig \
	drivers/pci/endpoint/Kconfig \
	drivers/pci/endpoint/functions/Kconfig \
	drivers/pci/switch/Kconfig \
	drivers/pci/pwrctrl/Kconfig \
	drivers/cxl/Kconfig \
	drivers/pcmcia/Kconfig \
	drivers/rapidio/Kconfig \
	drivers/rapidio/devices/Kconfig \
	drivers/rapidio/switches/Kconfig \
	drivers/base/Kconfig \
	drivers/base/firmware_loader/Kconfig \
	drivers/base/test/Kconfig \
	drivers/base/regmap/Kconfig \
	drivers/bus/Kconfig \
	drivers/bus/fsl-mc/Kconfig \
	drivers/bus/mhi/Kconfig \
	drivers/bus/mhi/host/Kconfig \
	drivers/bus/mhi/ep/Kconfig \
	drivers/cache/Kconfig \
	drivers/connector/Kconfig \
	drivers/firmware/Kconfig \
	drivers/firmware/arm_scmi/Kconfig \
	drivers/firmware/arm_scmi/transports/Kconfig \
	drivers/firmware/arm_scmi/vendors/imx/Kconfig \
	drivers/firmware/arm_ffa/Kconfig \
	drivers/firmware/broadcom/Kconfig \
	drivers/firmware/cirrus/Kconfig \
	drivers/firmware/google/Kconfig \
	drivers/firmware/efi/Kconfig \
	drivers/firmware/imx/Kconfig \
	drivers/firmware/meson/Kconfig \
	drivers/firmware/microchip/Kconfig \
	drivers/firmware/psci/Kconfig \
	drivers/firmware/qcom/Kconfig \
	drivers/firmware/samsung/Kconfig \
	drivers/firmware/smccc/Kconfig \
	drivers/firmware/tegra/Kconfig \
	drivers/firmware/xilinx/Kconfig \
	drivers/fwctl/Kconfig \
	drivers/gnss/Kconfig \
	drivers/mtd/Kconfig \
	drivers/mtd/parsers/Kconfig \
	drivers/mtd/chips/Kconfig \
	drivers/mtd/maps/Kconfig \
	drivers/mtd/devices/Kconfig \
	drivers/mtd/nand/Kconfig \
	drivers/mtd/nand/onenand/Kconfig \
	drivers/mtd/nand/raw/Kconfig \
	drivers/mtd/nand/raw/brcmnand/Kconfig \
	drivers/mtd/nand/raw/ingenic/Kconfig \
	drivers/mtd/nand/spi/Kconfig \
	drivers/mtd/lpddr/Kconfig \
	drivers/mtd/spi-nor/Kconfig \
	drivers/mtd/spi-nor/controllers/Kconfig \
	drivers/mtd/ubi/Kconfig \
	drivers/mtd/hyperbus/Kconfig \
	drivers/of/Kconfig \
	drivers/parport/Kconfig \
	drivers/pnp/Kconfig \
	drivers/pnp/isapnp/Kconfig \
	drivers/pnp/pnpbios/Kconfig \
	drivers/pnp/pnpacpi/Kconfig \
	drivers/block/Kconfig \
	drivers/block/null_blk/Kconfig \
	drivers/block/rnull/Kconfig \
	drivers/block/mtip32xx/Kconfig \
	drivers/block/zram/Kconfig \
	drivers/block/drbd/Kconfig \
	drivers/s390/block/Kconfig \
	drivers/block/rnbd/Kconfig \
	drivers/nvme/Kconfig \
	drivers/nvme/common/Kconfig \
	drivers/nvme/host/Kconfig \
	drivers/nvme/target/Kconfig \
	drivers/misc/Kconfig \
	drivers/misc/c2port/Kconfig \
	drivers/misc/eeprom/Kconfig \
	drivers/misc/cb710/Kconfig \
	drivers/misc/lis3lv02d/Kconfig \
	drivers/misc/altera-stapl/Kconfig \
	drivers/misc/mei/Kconfig \
	drivers/misc/mei/hdcp/Kconfig \
	drivers/misc/mei/pxp/Kconfig \
	drivers/misc/mei/gsc_proxy/Kconfig \
	drivers/misc/vmw_vmci/Kconfig \
	drivers/misc/genwqe/Kconfig \
	drivers/misc/ocxl/Kconfig \
	drivers/misc/bcm-vk/Kconfig \
	drivers/misc/cardreader/Kconfig \
	drivers/misc/uacce/Kconfig \
	drivers/misc/pvpanic/Kconfig \
	drivers/misc/mchp_pci1xxxx/Kconfig \
	drivers/misc/keba/Kconfig \
	drivers/misc/amd-sbi/Kconfig \
	drivers/misc/rp1/Kconfig \
	drivers/scsi/Kconfig \
	drivers/scsi/libsas/Kconfig \
	drivers/scsi/cxgbi/Kconfig \
	drivers/scsi/cxgbi/cxgb3i/Kconfig \
	drivers/scsi/cxgbi/cxgb4i/Kconfig \
	drivers/scsi/bnx2i/Kconfig \
	drivers/scsi/bnx2fc/Kconfig \
	drivers/scsi/be2iscsi/Kconfig \
	drivers/scsi/aic7xxx/Kconfig.aic7xxx \
	drivers/scsi/aic7xxx/Kconfig.aic79xx \
	drivers/scsi/aic94xx/Kconfig \
	drivers/scsi/hisi_sas/Kconfig \
	drivers/scsi/mvsas/Kconfig \
	drivers/scsi/esas2r/Kconfig \
	drivers/scsi/megaraid/Kconfig.megaraid \
	drivers/scsi/mpt3sas/Kconfig \
	drivers/scsi/mpi3mr/Kconfig \
	drivers/scsi/smartpqi/Kconfig \
	drivers/scsi/qla2xxx/Kconfig \
	drivers/scsi/qla4xxx/Kconfig \
	drivers/scsi/qedi/Kconfig \
	drivers/scsi/qedf/Kconfig \
	drivers/scsi/elx/Kconfig \
	drivers/scsi/arm/Kconfig \
	drivers/scsi/csiostor/Kconfig \
	drivers/scsi/pcmcia/Kconfig \
	drivers/scsi/device_handler/Kconfig \
	drivers/ata/Kconfig \
	drivers/ata/pata_parport/Kconfig \
	drivers/md/Kconfig \
	drivers/md/bcache/Kconfig \
	drivers/md/persistent-data/Kconfig \
	drivers/md/dm-vdo/Kconfig \
	drivers/md/dm-pcache/Kconfig \
	drivers/target/Kconfig \
	drivers/target/loopback/Kconfig \
	drivers/target/tcm_fc/Kconfig \
	drivers/target/iscsi/Kconfig \
	drivers/target/iscsi/cxgbit/Kconfig \
	drivers/target/sbp/Kconfig \
	drivers/target/tcm_remote/Kconfig \
	drivers/message/fusion/Kconfig \
	drivers/firewire/Kconfig \
	drivers/macintosh/Kconfig \
	drivers/net/Kconfig \
	drivers/net/team/Kconfig \
	drivers/net/arcnet/Kconfig \
	drivers/atm/Kconfig \
	drivers/net/caif/Kconfig \
	drivers/net/dsa/Kconfig \
	drivers/net/dsa/b53/Kconfig \
	drivers/net/dsa/hirschmann/Kconfig \
	drivers/net/dsa/lantiq/Kconfig \
	drivers/net/dsa/microchip/Kconfig \
	drivers/net/dsa/mv88e6xxx/Kconfig \
	drivers/net/dsa/mxl862xx/Kconfig \
	drivers/net/dsa/ocelot/Kconfig \
	drivers/net/dsa/qca/Kconfig \
	drivers/net/dsa/sja1105/Kconfig \
	drivers/net/dsa/xrs700x/Kconfig \
	drivers/net/dsa/realtek/Kconfig \
	drivers/net/ethernet/Kconfig \
	drivers/net/ethernet/3com/Kconfig \
	drivers/net/ethernet/actions/Kconfig \
	drivers/net/ethernet/adaptec/Kconfig \
	drivers/net/ethernet/aeroflex/Kconfig \
	drivers/net/ethernet/agere/Kconfig \
	drivers/net/ethernet/airoha/Kconfig \
	drivers/net/ethernet/alacritech/Kconfig \
	drivers/net/ethernet/allwinner/Kconfig \
	drivers/net/ethernet/alteon/Kconfig \
	drivers/net/ethernet/altera/Kconfig \
	drivers/net/ethernet/amazon/Kconfig \
	drivers/net/ethernet/amd/Kconfig \
	drivers/net/ethernet/apm/Kconfig \
	drivers/net/ethernet/apm/xgene/Kconfig \
	drivers/net/ethernet/apm/xgene-v2/Kconfig \
	drivers/net/ethernet/apple/Kconfig \
	drivers/net/ethernet/aquantia/Kconfig \
	drivers/net/ethernet/arc/Kconfig \
	drivers/net/ethernet/asix/Kconfig \
	drivers/net/ethernet/atheros/Kconfig \
	drivers/net/ethernet/broadcom/Kconfig \
	drivers/net/ethernet/cadence/Kconfig \
	drivers/net/ethernet/calxeda/Kconfig \
	drivers/net/ethernet/cavium/Kconfig \
	drivers/net/ethernet/chelsio/Kconfig \
	drivers/net/ethernet/chelsio/inline_crypto/Kconfig \
	drivers/net/ethernet/cirrus/Kconfig \
	drivers/net/ethernet/cisco/Kconfig \
	drivers/net/ethernet/cisco/enic/Kconfig \
	drivers/net/ethernet/cortina/Kconfig \
	drivers/net/ethernet/davicom/Kconfig \
	drivers/net/ethernet/dec/Kconfig \
	drivers/net/ethernet/dec/tulip/Kconfig \
	drivers/net/ethernet/dlink/Kconfig \
	drivers/net/ethernet/emulex/Kconfig \
	drivers/net/ethernet/emulex/benet/Kconfig \
	drivers/net/ethernet/engleder/Kconfig \
	drivers/net/ethernet/ezchip/Kconfig \
	drivers/net/ethernet/faraday/Kconfig \
	drivers/net/ethernet/freescale/Kconfig \
	drivers/net/ethernet/freescale/fs_enet/Kconfig \
	drivers/net/ethernet/freescale/fman/Kconfig \
	drivers/net/ethernet/freescale/dpaa/Kconfig \
	drivers/net/ethernet/freescale/dpaa2/Kconfig \
	drivers/net/ethernet/freescale/enetc/Kconfig \
	drivers/net/ethernet/fujitsu/Kconfig \
	drivers/net/ethernet/fungible/Kconfig \
	drivers/net/ethernet/fungible/funeth/Kconfig \
	drivers/net/ethernet/google/Kconfig \
	drivers/net/ethernet/hisilicon/Kconfig \
	drivers/net/ethernet/huawei/Kconfig \
	drivers/net/ethernet/huawei/hinic/Kconfig \
	drivers/net/ethernet/huawei/hinic3/Kconfig \
	drivers/net/ethernet/i825xx/Kconfig \
	drivers/net/ethernet/ibm/Kconfig \
	drivers/net/ethernet/ibm/emac/Kconfig \
	drivers/net/ethernet/intel/Kconfig \
	drivers/net/ethernet/intel/libeth/Kconfig \
	drivers/net/ethernet/intel/libie/Kconfig \
	drivers/net/ethernet/intel/idpf/Kconfig \
	drivers/net/ethernet/xscale/Kconfig \
	drivers/net/ethernet/adi/Kconfig \
	drivers/net/ethernet/litex/Kconfig \
	drivers/net/ethernet/marvell/Kconfig \
	drivers/net/ethernet/marvell/octeontx2/Kconfig \
	drivers/net/ethernet/marvell/octeon_ep/Kconfig \
	drivers/net/ethernet/marvell/octeon_ep_vf/Kconfig \
	drivers/net/ethernet/marvell/prestera/Kconfig \
	drivers/net/ethernet/mediatek/Kconfig \
	drivers/net/ethernet/mellanox/Kconfig \
	drivers/net/ethernet/mellanox/mlx4/Kconfig \
	drivers/net/ethernet/mellanox/mlx5/core/Kconfig \
	drivers/net/ethernet/mellanox/mlxsw/Kconfig \
	drivers/net/ethernet/mellanox/mlxfw/Kconfig \
	drivers/net/ethernet/mellanox/mlxbf_gige/Kconfig \
	drivers/net/ethernet/meta/Kconfig \
	drivers/net/ethernet/micrel/Kconfig \
	drivers/net/ethernet/microchip/Kconfig \
	drivers/net/ethernet/microchip/lan865x/Kconfig \
	drivers/net/ethernet/microchip/lan966x/Kconfig \
	drivers/net/ethernet/microchip/sparx5/Kconfig \
	drivers/net/ethernet/microchip/vcap/Kconfig \
	drivers/net/ethernet/microchip/fdma/Kconfig \
	drivers/net/ethernet/mscc/Kconfig \
	drivers/net/ethernet/microsoft/Kconfig \
	drivers/net/ethernet/moxa/Kconfig \
	drivers/net/ethernet/mucse/Kconfig \
	drivers/net/ethernet/myricom/Kconfig \
	drivers/net/ethernet/ni/Kconfig \
	drivers/net/ethernet/natsemi/Kconfig \
	drivers/net/ethernet/netronome/Kconfig \
	drivers/net/ethernet/8390/Kconfig \
	drivers/net/ethernet/nvidia/Kconfig \
	drivers/net/ethernet/nxp/Kconfig \
	drivers/net/ethernet/oki-semi/Kconfig \
	drivers/net/ethernet/oki-semi/pch_gbe/Kconfig \
	drivers/net/ethernet/packetengines/Kconfig \
	drivers/net/ethernet/pasemi/Kconfig \
	drivers/net/ethernet/pensando/Kconfig \
	drivers/net/ethernet/qlogic/Kconfig \
	drivers/net/ethernet/brocade/Kconfig \
	drivers/net/ethernet/brocade/bna/Kconfig \
	drivers/net/ethernet/qualcomm/Kconfig \
	drivers/net/ethernet/qualcomm/rmnet/Kconfig \
	drivers/net/ethernet/rdc/Kconfig \
	drivers/net/ethernet/realtek/Kconfig \
	drivers/net/ethernet/renesas/Kconfig \
	drivers/net/ethernet/rocker/Kconfig \
	drivers/net/ethernet/samsung/Kconfig \
	drivers/net/ethernet/seeq/Kconfig \
	drivers/net/ethernet/sgi/Kconfig \
	drivers/net/ethernet/silan/Kconfig \
	drivers/net/ethernet/sis/Kconfig \
	drivers/net/ethernet/sfc/Kconfig \
	drivers/net/ethernet/sfc/falcon/Kconfig \
	drivers/net/ethernet/sfc/siena/Kconfig \
	drivers/net/ethernet/smsc/Kconfig \
	drivers/net/ethernet/socionext/Kconfig \
	drivers/net/ethernet/spacemit/Kconfig \
	drivers/net/ethernet/stmicro/Kconfig \
	drivers/net/ethernet/stmicro/stmmac/Kconfig \
	drivers/net/ethernet/sun/Kconfig \
	drivers/net/ethernet/sunplus/Kconfig \
	drivers/net/ethernet/synopsys/Kconfig \
	drivers/net/ethernet/tehuti/Kconfig \
	drivers/net/ethernet/ti/Kconfig \
	drivers/net/ethernet/toshiba/Kconfig \
	drivers/net/ethernet/tundra/Kconfig \
	drivers/net/ethernet/vertexcom/Kconfig \
	drivers/net/ethernet/via/Kconfig \
	drivers/net/ethernet/wangxun/Kconfig \
	drivers/net/ethernet/wiznet/Kconfig \
	drivers/net/ethernet/xilinx/Kconfig \
	drivers/net/ethernet/xircom/Kconfig \
	drivers/net/fddi/Kconfig \
	drivers/net/ipa/Kconfig \
	drivers/net/phy/Kconfig \
	drivers/net/phy/aquantia/Kconfig \
	drivers/net/phy/mediatek/Kconfig \
	drivers/net/phy/qcom/Kconfig \
	drivers/net/phy/realtek/Kconfig \
	drivers/net/pse-pd/Kconfig \
	drivers/net/can/Kconfig \
	drivers/net/can/c_can/Kconfig \
	drivers/net/can/cc770/Kconfig \
	drivers/net/can/ctucanfd/Kconfig \
	drivers/net/can/esd/Kconfig \
	drivers/net/can/ifi_canfd/Kconfig \
	drivers/net/can/m_can/Kconfig \
	drivers/net/can/mscan/Kconfig \
	drivers/net/can/peak_canfd/Kconfig \
	drivers/net/can/rcar/Kconfig \
	drivers/net/can/rockchip/Kconfig \
	drivers/net/can/sja1000/Kconfig \
	drivers/net/can/softing/Kconfig \
	drivers/net/can/spi/Kconfig \
	drivers/net/can/spi/mcp251xfd/Kconfig \
	drivers/net/can/usb/Kconfig \
	drivers/net/mctp/Kconfig \
	drivers/net/mdio/Kconfig \
	drivers/net/pcs/Kconfig \
	drivers/net/plip/Kconfig \
	drivers/net/ppp/Kconfig \
	drivers/net/slip/Kconfig \
	drivers/s390/net/Kconfig \
	drivers/net/usb/Kconfig \
	drivers/net/wireless/Kconfig \
	drivers/net/wireless/admtek/Kconfig \
	drivers/net/wireless/ath/Kconfig \
	drivers/net/wireless/ath/ath5k/Kconfig \
	drivers/net/wireless/ath/ath9k/Kconfig \
	drivers/net/wireless/ath/carl9170/Kconfig \
	drivers/net/wireless/ath/ath6kl/Kconfig \
	drivers/net/wireless/ath/ar5523/Kconfig \
	drivers/net/wireless/ath/wil6210/Kconfig \
	drivers/net/wireless/ath/ath10k/Kconfig \
	drivers/net/wireless/ath/wcn36xx/Kconfig \
	drivers/net/wireless/ath/ath11k/Kconfig \
	drivers/net/wireless/ath/ath12k/Kconfig \
	drivers/net/wireless/atmel/Kconfig \
	drivers/net/wireless/broadcom/Kconfig \
	drivers/net/wireless/broadcom/b43/Kconfig \
	drivers/net/wireless/broadcom/b43legacy/Kconfig \
	drivers/net/wireless/broadcom/brcm80211/Kconfig \
	drivers/net/wireless/broadcom/brcm80211/brcmfmac/Kconfig \
	drivers/net/wireless/intel/Kconfig \
	drivers/net/wireless/intel/ipw2x00/Kconfig \
	drivers/net/wireless/intel/iwlegacy/Kconfig \
	drivers/net/wireless/intel/iwlwifi/Kconfig \
	drivers/net/wireless/intersil/Kconfig \
	drivers/net/wireless/intersil/p54/Kconfig \
	drivers/net/wireless/marvell/Kconfig \
	drivers/net/wireless/marvell/libertas/Kconfig \
	drivers/net/wireless/marvell/libertas_tf/Kconfig \
	drivers/net/wireless/marvell/mwifiex/Kconfig \
	drivers/net/wireless/mediatek/Kconfig \
	drivers/net/wireless/mediatek/mt7601u/Kconfig \
	drivers/net/wireless/mediatek/mt76/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt76x0/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt76x2/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt7603/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt7615/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt7915/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt7921/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt7996/Kconfig \
	drivers/net/wireless/mediatek/mt76/mt7925/Kconfig \
	drivers/net/wireless/microchip/Kconfig \
	drivers/net/wireless/microchip/wilc1000/Kconfig \
	drivers/net/wireless/purelifi/Kconfig \
	drivers/net/wireless/purelifi/plfxlc/Kconfig \
	drivers/net/wireless/ralink/Kconfig \
	drivers/net/wireless/ralink/rt2x00/Kconfig \
	drivers/net/wireless/realtek/Kconfig \
	drivers/net/wireless/realtek/rtl818x/Kconfig \
	drivers/net/wireless/realtek/rtlwifi/Kconfig \
	drivers/net/wireless/realtek/rtl8xxxu/Kconfig \
	drivers/net/wireless/realtek/rtw88/Kconfig \
	drivers/net/wireless/realtek/rtw89/Kconfig \
	drivers/net/wireless/rsi/Kconfig \
	drivers/net/wireless/silabs/Kconfig \
	drivers/net/wireless/silabs/wfx/Kconfig \
	drivers/net/wireless/st/Kconfig \
	drivers/net/wireless/st/cw1200/Kconfig \
	drivers/net/wireless/ti/Kconfig \
	drivers/net/wireless/ti/wl1251/Kconfig \
	drivers/net/wireless/ti/wl12xx/Kconfig \
	drivers/net/wireless/ti/wl18xx/Kconfig \
	drivers/net/wireless/ti/wlcore/Kconfig \
	drivers/net/wireless/zydas/Kconfig \
	drivers/net/wireless/zydas/zd1211rw/Kconfig \
	drivers/net/wireless/quantenna/Kconfig \
	drivers/net/wireless/quantenna/qtnfmac/Kconfig \
	drivers/net/wireless/virtual/Kconfig \
	drivers/net/wan/Kconfig \
	drivers/net/wan/framer/Kconfig \
	drivers/net/ieee802154/Kconfig \
	drivers/net/wwan/Kconfig \
	drivers/net/thunderbolt/Kconfig \
	drivers/net/hyperv/Kconfig \
	drivers/isdn/Kconfig \
	drivers/isdn/capi/Kconfig \
	drivers/isdn/mISDN/Kconfig \
	drivers/isdn/hardware/mISDN/Kconfig \
	drivers/input/Kconfig \
	drivers/input/keyboard/Kconfig \
	drivers/input/mouse/Kconfig \
	drivers/input/joystick/Kconfig \
	drivers/input/joystick/iforce/Kconfig \
	drivers/input/tablet/Kconfig \
	drivers/input/touchscreen/Kconfig \
	drivers/input/misc/Kconfig \
	drivers/input/rmi4/Kconfig \
	drivers/input/serio/Kconfig \
	drivers/input/gameport/Kconfig \
	drivers/char/Kconfig \
	drivers/tty/Kconfig \
	drivers/tty/serial/Kconfig \
	drivers/tty/serial/8250/Kconfig \
	drivers/tty/hvc/Kconfig \
	drivers/tty/serdev/Kconfig \
	drivers/char/ipmi/Kconfig \
	drivers/char/hw_random/Kconfig \
	drivers/char/tpm/Kconfig \
	drivers/char/tpm/st33zp24/Kconfig \
	drivers/s390/char/Kconfig \
	drivers/char/xillybus/Kconfig \
	drivers/i2c/Kconfig \
	drivers/i2c/muxes/Kconfig \
	drivers/i2c/algos/Kconfig \
	drivers/i2c/busses/Kconfig \
	drivers/i3c/Kconfig \
	drivers/i3c/master/Kconfig \
	drivers/spi/Kconfig \
	drivers/spmi/Kconfig \
	drivers/hsi/Kconfig \
	drivers/hsi/controllers/Kconfig \
	drivers/hsi/clients/Kconfig \
	drivers/pps/Kconfig \
	drivers/pps/clients/Kconfig \
	drivers/pps/generators/Kconfig \
	drivers/ptp/Kconfig \
	drivers/dpll/Kconfig \
	drivers/dpll/zl3073x/Kconfig \
	drivers/pinctrl/Kconfig \
	drivers/pinctrl/actions/Kconfig \
	drivers/pinctrl/aspeed/Kconfig \
	drivers/pinctrl/bcm/Kconfig \
	drivers/pinctrl/bcm/Kconfig.stb \
	drivers/pinctrl/berlin/Kconfig \
	drivers/pinctrl/cirrus/Kconfig \
	drivers/pinctrl/cix/Kconfig \
	drivers/pinctrl/freescale/Kconfig \
	drivers/pinctrl/intel/Kconfig \
	drivers/pinctrl/intel/Kconfig.tng \
	drivers/pinctrl/mediatek/Kconfig \
	drivers/pinctrl/meson/Kconfig \
	drivers/pinctrl/microchip/Kconfig \
	drivers/pinctrl/mvebu/Kconfig \
	drivers/pinctrl/nomadik/Kconfig \
	drivers/pinctrl/nuvoton/Kconfig \
	drivers/pinctrl/nxp/Kconfig \
	drivers/pinctrl/pxa/Kconfig \
	drivers/pinctrl/qcom/Kconfig \
	drivers/pinctrl/qcom/Kconfig.msm \
	drivers/pinctrl/realtek/Kconfig \
	drivers/pinctrl/renesas/Kconfig \
	drivers/pinctrl/samsung/Kconfig \
	drivers/pinctrl/sophgo/Kconfig \
	drivers/pinctrl/spacemit/Kconfig \
	drivers/pinctrl/spear/Kconfig \
	drivers/pinctrl/sprd/Kconfig \
	drivers/pinctrl/starfive/Kconfig \
	drivers/pinctrl/stm32/Kconfig \
	drivers/pinctrl/sunplus/Kconfig \
	drivers/pinctrl/sunxi/Kconfig \
	drivers/pinctrl/tegra/Kconfig \
	drivers/pinctrl/ti/Kconfig \
	drivers/pinctrl/uniphier/Kconfig \
	drivers/pinctrl/visconti/Kconfig \
	drivers/pinctrl/vt8500/Kconfig \
	drivers/gpio/Kconfig \
	drivers/w1/Kconfig \
	drivers/w1/masters/Kconfig \
	drivers/w1/slaves/Kconfig \
	drivers/power/Kconfig \
	drivers/power/reset/Kconfig \
	drivers/power/sequencing/Kconfig \
	drivers/power/supply/Kconfig \
	drivers/hwmon/Kconfig \
	drivers/hwmon/occ/Kconfig \
	drivers/hwmon/peci/Kconfig \
	drivers/hwmon/pmbus/Kconfig \
	drivers/thermal/Kconfig \
	drivers/thermal/mediatek/Kconfig \
	drivers/thermal/intel/Kconfig \
	drivers/thermal/intel/int340x_thermal/Kconfig \
	drivers/thermal/broadcom/Kconfig \
	drivers/thermal/ti-soc-thermal/Kconfig \
	drivers/thermal/samsung/Kconfig \
	drivers/thermal/st/Kconfig \
	drivers/thermal/renesas/Kconfig \
	drivers/thermal/tegra/Kconfig \
	drivers/thermal/qcom/Kconfig \
	drivers/watchdog/Kconfig \
	drivers/ssb/Kconfig \
	drivers/bcma/Kconfig \
	drivers/mfd/Kconfig \
	drivers/regulator/Kconfig \
	drivers/media/Kconfig \
	drivers/media/rc/Kconfig \
	drivers/media/rc/keymaps/Kconfig \
	drivers/media/rc/img-ir/Kconfig \
	drivers/media/cec/Kconfig \
	drivers/media/cec/i2c/Kconfig \
	drivers/media/cec/platform/Kconfig \
	drivers/media/cec/usb/Kconfig \
	drivers/media/cec/usb/extron-da-hd-4k-plus/Kconfig \
	drivers/media/cec/usb/pulse8/Kconfig \
	drivers/media/cec/usb/rainshadow/Kconfig \
	drivers/media/v4l2-core/Kconfig \
	drivers/media/mc/Kconfig \
	drivers/media/dvb-core/Kconfig \
	drivers/media/usb/Kconfig \
	drivers/media/usb/gspca/Kconfig \
	drivers/media/usb/gspca/gl860/Kconfig \
	drivers/media/usb/gspca/m5602/Kconfig \
	drivers/media/usb/gspca/stv06xx/Kconfig \
	drivers/media/usb/pwc/Kconfig \
	drivers/media/usb/s2255/Kconfig \
	drivers/media/usb/usbtv/Kconfig \
	drivers/media/usb/uvc/Kconfig \
	drivers/media/usb/go7007/Kconfig \
	drivers/media/usb/hdpvr/Kconfig \
	drivers/media/usb/pvrusb2/Kconfig \
	drivers/media/usb/stk1160/Kconfig \
	drivers/media/usb/au0828/Kconfig \
	drivers/media/usb/cx231xx/Kconfig \
	drivers/media/usb/as102/Kconfig \
	drivers/media/usb/b2c2/Kconfig \
	drivers/media/usb/dvb-usb-v2/Kconfig \
	drivers/media/usb/dvb-usb/Kconfig \
	drivers/media/usb/siano/Kconfig \
	drivers/media/usb/ttusb-budget/Kconfig \
	drivers/media/usb/ttusb-dec/Kconfig \
	drivers/media/usb/em28xx/Kconfig \
	drivers/media/usb/airspy/Kconfig \
	drivers/media/usb/hackrf/Kconfig \
	drivers/media/usb/msi2500/Kconfig \
	drivers/media/pci/Kconfig \
	drivers/media/pci/mgb4/Kconfig \
	drivers/media/pci/solo6x10/Kconfig \
	drivers/media/pci/tw5864/Kconfig \
	drivers/media/pci/tw68/Kconfig \
	drivers/media/pci/tw686x/Kconfig \
	drivers/media/pci/zoran/Kconfig \
	drivers/media/pci/dt3155/Kconfig \
	drivers/media/pci/ivtv/Kconfig \
	drivers/media/pci/saa7146/Kconfig \
	drivers/media/pci/bt8xx/Kconfig \
	drivers/media/pci/cobalt/Kconfig \
	drivers/media/pci/cx18/Kconfig \
	drivers/media/pci/cx23885/Kconfig \
	drivers/media/pci/cx25821/Kconfig \
	drivers/media/pci/cx88/Kconfig \
	drivers/media/pci/saa7134/Kconfig \
	drivers/media/pci/saa7164/Kconfig \
	drivers/media/pci/b2c2/Kconfig \
	drivers/media/pci/ddbridge/Kconfig \
	drivers/media/pci/dm1105/Kconfig \
	drivers/media/pci/mantis/Kconfig \
	drivers/media/pci/netup_unidvb/Kconfig \
	drivers/media/pci/ngene/Kconfig \
	drivers/media/pci/pluto2/Kconfig \
	drivers/media/pci/pt1/Kconfig \
	drivers/media/pci/pt3/Kconfig \
	drivers/media/pci/smipcie/Kconfig \
	drivers/media/pci/ttpci/Kconfig \
	drivers/media/pci/intel/Kconfig \
	drivers/media/pci/intel/ipu3/Kconfig \
	drivers/media/pci/intel/ipu6/Kconfig \
	drivers/media/pci/intel/ivsc/Kconfig \
	drivers/media/radio/Kconfig \
	drivers/media/radio/si470x/Kconfig \
	drivers/media/radio/si4713/Kconfig \
	drivers/media/platform/Kconfig \
	drivers/media/platform/allegro-dvt/Kconfig \
	drivers/media/platform/amlogic/Kconfig \
	drivers/media/platform/amlogic/c3/Kconfig \
	drivers/media/platform/amlogic/c3/isp/Kconfig \
	drivers/media/platform/amlogic/c3/mipi-adapter/Kconfig \
	drivers/media/platform/amlogic/c3/mipi-csi2/Kconfig \
	drivers/media/platform/amlogic/meson-ge2d/Kconfig \
	drivers/media/platform/amphion/Kconfig \
	drivers/media/platform/arm/Kconfig \
	drivers/media/platform/arm/mali-c55/Kconfig \
	drivers/media/platform/aspeed/Kconfig \
	drivers/media/platform/atmel/Kconfig \
	drivers/media/platform/broadcom/Kconfig \
	drivers/media/platform/cadence/Kconfig \
	drivers/media/platform/chips-media/Kconfig \
	drivers/media/platform/chips-media/coda/Kconfig \
	drivers/media/platform/chips-media/wave5/Kconfig \
	drivers/media/platform/imagination/Kconfig \
	drivers/media/platform/intel/Kconfig \
	drivers/media/platform/marvell/Kconfig \
	drivers/media/platform/mediatek/Kconfig \
	drivers/media/platform/mediatek/jpeg/Kconfig \
	drivers/media/platform/mediatek/mdp/Kconfig \
	drivers/media/platform/mediatek/vcodec/Kconfig \
	drivers/media/platform/mediatek/vpu/Kconfig \
	drivers/media/platform/mediatek/mdp3/Kconfig \
	drivers/media/platform/microchip/Kconfig \
	drivers/media/platform/nuvoton/Kconfig \
	drivers/media/platform/nvidia/Kconfig \
	drivers/media/platform/nvidia/tegra-vde/Kconfig \
	drivers/media/platform/nxp/Kconfig \
	drivers/media/platform/nxp/imx8-isi/Kconfig \
	drivers/media/platform/nxp/dw100/Kconfig \
	drivers/media/platform/nxp/imx-jpeg/Kconfig \
	drivers/media/platform/qcom/Kconfig \
	drivers/media/platform/qcom/camss/Kconfig \
	drivers/media/platform/qcom/iris/Kconfig \
	drivers/media/platform/qcom/venus/Kconfig \
	drivers/media/platform/raspberrypi/Kconfig \
	drivers/media/platform/raspberrypi/pisp_be/Kconfig \
	drivers/media/platform/raspberrypi/rp1-cfe/Kconfig \
	drivers/media/platform/renesas/Kconfig \
	drivers/media/platform/renesas/rcar-isp/Kconfig \
	drivers/media/platform/renesas/rcar-vin/Kconfig \
	drivers/media/platform/renesas/rzg2l-cru/Kconfig \
	drivers/media/platform/renesas/rzv2h-ivc/Kconfig \
	drivers/media/platform/rockchip/Kconfig \
	drivers/media/platform/rockchip/rga/Kconfig \
	drivers/media/platform/rockchip/rkcif/Kconfig \
	drivers/media/platform/rockchip/rkisp1/Kconfig \
	drivers/media/platform/rockchip/rkvdec/Kconfig \
	drivers/media/platform/samsung/Kconfig \
	drivers/media/platform/samsung/exynos-gsc/Kconfig \
	drivers/media/platform/samsung/exynos4-is/Kconfig \
	drivers/media/platform/samsung/s3c-camif/Kconfig \
	drivers/media/platform/samsung/s5p-g2d/Kconfig \
	drivers/media/platform/samsung/s5p-jpeg/Kconfig \
	drivers/media/platform/samsung/s5p-mfc/Kconfig \
	drivers/media/platform/st/Kconfig \
	drivers/media/platform/st/sti/Kconfig \
	drivers/media/platform/st/sti/bdisp/Kconfig \
	drivers/media/platform/st/sti/delta/Kconfig \
	drivers/media/platform/st/sti/hva/Kconfig \
	drivers/media/platform/st/stm32/Kconfig \
	drivers/media/platform/sunxi/Kconfig \
	drivers/media/platform/sunxi/sun4i-csi/Kconfig \
	drivers/media/platform/sunxi/sun6i-csi/Kconfig \
	drivers/media/platform/sunxi/sun6i-mipi-csi2/Kconfig \
	drivers/media/platform/sunxi/sun8i-a83t-mipi-csi2/Kconfig \
	drivers/media/platform/sunxi/sun8i-di/Kconfig \
	drivers/media/platform/sunxi/sun8i-rotate/Kconfig \
	drivers/media/platform/synopsys/Kconfig \
	drivers/media/platform/synopsys/hdmirx/Kconfig \
	drivers/media/platform/ti/Kconfig \
	drivers/media/platform/ti/am437x/Kconfig \
	drivers/media/platform/ti/davinci/Kconfig \
	drivers/media/platform/ti/omap/Kconfig \
	drivers/media/platform/ti/omap3isp/Kconfig \
	drivers/media/platform/verisilicon/Kconfig \
	drivers/media/platform/via/Kconfig \
	drivers/media/platform/xilinx/Kconfig \
	drivers/media/mmc/Kconfig \
	drivers/media/mmc/siano/Kconfig \
	drivers/media/test-drivers/Kconfig \
	drivers/media/test-drivers/vicodec/Kconfig \
	drivers/media/test-drivers/vimc/Kconfig \
	drivers/media/test-drivers/vivid/Kconfig \
	drivers/media/test-drivers/visl/Kconfig \
	drivers/media/test-drivers/vidtv/Kconfig \
	drivers/media/firewire/Kconfig \
	drivers/media/common/Kconfig \
	drivers/media/common/b2c2/Kconfig \
	drivers/media/common/saa7146/Kconfig \
	drivers/media/common/siano/Kconfig \
	drivers/media/common/v4l2-tpg/Kconfig \
	drivers/media/common/videobuf2/Kconfig \
	drivers/media/i2c/Kconfig \
	drivers/media/i2c/ccs/Kconfig \
	drivers/media/i2c/et8ek8/Kconfig \
	drivers/media/i2c/cx25840/Kconfig \
	drivers/media/spi/Kconfig \
	drivers/media/tuners/Kconfig \
	drivers/media/dvb-frontends/Kconfig \
	drivers/media/dvb-frontends/cxd2880/Kconfig \
	drivers/media/dvb-frontends/drx39xyj/Kconfig \
	drivers/video/Kconfig \
	drivers/auxdisplay/Kconfig \
	drivers/char/agp/Kconfig \
	drivers/gpu/vga/Kconfig \
	drivers/gpu/host1x/Kconfig \
	drivers/gpu/ipu-v3/Kconfig \
	drivers/gpu/nova-core/Kconfig \
	drivers/gpu/drm/Kconfig \
	drivers/gpu/drm/Kconfig.debug \
	drivers/gpu/drm/clients/Kconfig \
	drivers/gpu/drm/display/Kconfig \
	drivers/gpu/drm/adp/Kconfig \
	drivers/gpu/drm/amd/amdgpu/Kconfig \
	drivers/gpu/drm/amd/acp/Kconfig \
	drivers/gpu/drm/amd/display/Kconfig \
	drivers/gpu/drm/amd/amdkfd/Kconfig \
	drivers/gpu/drm/arm/Kconfig \
	drivers/gpu/drm/arm/display/Kconfig \
	drivers/gpu/drm/armada/Kconfig \
	drivers/gpu/drm/aspeed/Kconfig \
	drivers/gpu/drm/ast/Kconfig \
	drivers/gpu/drm/atmel-hlcdc/Kconfig \
	drivers/gpu/drm/bridge/Kconfig \
	drivers/gpu/drm/bridge/analogix/Kconfig \
	drivers/gpu/drm/bridge/adv7511/Kconfig \
	drivers/gpu/drm/bridge/cadence/Kconfig \
	drivers/gpu/drm/bridge/imx/Kconfig \
	drivers/gpu/drm/bridge/synopsys/Kconfig \
	drivers/gpu/drm/etnaviv/Kconfig \
	drivers/gpu/drm/exynos/Kconfig \
	drivers/gpu/drm/fsl-dcu/Kconfig \
	drivers/gpu/drm/gma500/Kconfig \
	drivers/gpu/drm/gud/Kconfig \
	drivers/gpu/drm/hisilicon/Kconfig \
	drivers/gpu/drm/hisilicon/hibmc/Kconfig \
	drivers/gpu/drm/hisilicon/kirin/Kconfig \
	drivers/gpu/drm/hyperv/Kconfig \
	drivers/gpu/drm/i915/Kconfig \
	drivers/gpu/drm/i915/Kconfig.debug \
	drivers/gpu/drm/i915/Kconfig.profile \
	drivers/gpu/drm/imagination/Kconfig \
	drivers/gpu/drm/imx/Kconfig \
	drivers/gpu/drm/imx/dc/Kconfig \
	drivers/gpu/drm/imx/dcss/Kconfig \
	drivers/gpu/drm/imx/ipuv3/Kconfig \
	drivers/gpu/drm/imx/lcdc/Kconfig \
	drivers/gpu/drm/ingenic/Kconfig \
	drivers/gpu/drm/kmb/Kconfig \
	drivers/gpu/drm/lima/Kconfig \
	drivers/gpu/drm/logicvc/Kconfig \
	drivers/gpu/drm/loongson/Kconfig \
	drivers/gpu/drm/mcde/Kconfig \
	drivers/gpu/drm/mediatek/Kconfig \
	drivers/gpu/drm/meson/Kconfig \
	drivers/gpu/drm/mgag200/Kconfig \
	drivers/gpu/drm/msm/Kconfig \
	drivers/gpu/drm/mxsfb/Kconfig \
	drivers/gpu/drm/nouveau/Kconfig \
	drivers/gpu/drm/nova/Kconfig \
	drivers/gpu/drm/omapdrm/Kconfig \
	drivers/gpu/drm/panel/Kconfig \
	drivers/gpu/drm/panfrost/Kconfig \
	drivers/gpu/drm/panthor/Kconfig \
	drivers/gpu/drm/pl111/Kconfig \
	drivers/gpu/drm/qxl/Kconfig \
	drivers/gpu/drm/radeon/Kconfig \
	drivers/gpu/drm/renesas/Kconfig \
	drivers/gpu/drm/renesas/rcar-du/Kconfig \
	drivers/gpu/drm/renesas/rz-du/Kconfig \
	drivers/gpu/drm/renesas/shmobile/Kconfig \
	drivers/gpu/drm/rockchip/Kconfig \
	drivers/gpu/drm/sitronix/Kconfig \
	drivers/gpu/drm/solomon/Kconfig \
	drivers/gpu/drm/sprd/Kconfig \
	drivers/gpu/drm/sti/Kconfig \
	drivers/gpu/drm/stm/Kconfig \
	drivers/gpu/drm/sun4i/Kconfig \
	drivers/gpu/drm/sysfb/Kconfig \
	drivers/gpu/drm/tegra/Kconfig \
	drivers/gpu/drm/tidss/Kconfig \
	drivers/gpu/drm/tilcdc/Kconfig \
	drivers/gpu/drm/tiny/Kconfig \
	drivers/gpu/drm/tve200/Kconfig \
	drivers/gpu/drm/tyr/Kconfig \
	drivers/gpu/drm/udl/Kconfig \
	drivers/gpu/drm/v3d/Kconfig \
	drivers/gpu/drm/vboxvideo/Kconfig \
	drivers/gpu/drm/vc4/Kconfig \
	drivers/gpu/drm/vgem/Kconfig \
	drivers/gpu/drm/virtio/Kconfig \
	drivers/gpu/drm/vkms/Kconfig \
	drivers/gpu/drm/vmwgfx/Kconfig \
	drivers/gpu/drm/xe/Kconfig \
	drivers/gpu/drm/xe/Kconfig.debug \
	drivers/gpu/drm/xe/Kconfig.profile \
	drivers/gpu/drm/xen/Kconfig \
	drivers/gpu/drm/xlnx/Kconfig \
	drivers/video/fbdev/Kconfig \
	drivers/video/fbdev/geode/Kconfig \
	drivers/video/fbdev/omap/Kconfig \
	drivers/video/fbdev/omap2/Kconfig \
	drivers/video/fbdev/omap2/omapfb/Kconfig \
	drivers/video/fbdev/omap2/omapfb/dss/Kconfig \
	drivers/video/fbdev/omap2/omapfb/displays/Kconfig \
	drivers/video/fbdev/mmp/Kconfig \
	drivers/video/fbdev/mmp/hw/Kconfig \
	drivers/video/fbdev/mmp/panel/Kconfig \
	drivers/video/fbdev/mmp/fb/Kconfig \
	drivers/video/fbdev/core/Kconfig \
	drivers/video/backlight/Kconfig \
	drivers/video/console/Kconfig \
	drivers/video/logo/Kconfig \
	drivers/gpu/trace/Kconfig \
	drivers/accel/Kconfig \
	drivers/accel/amdxdna/Kconfig \
	drivers/accel/ethosu/Kconfig \
	drivers/accel/habanalabs/Kconfig \
	drivers/accel/ivpu/Kconfig \
	drivers/accel/qaic/Kconfig \
	drivers/accel/rocket/Kconfig \
	sound/Kconfig \
	sound/oss/dmasound/Kconfig \
	sound/core/Kconfig \
	sound/core/seq/Kconfig \
	sound/drivers/Kconfig \
	sound/isa/Kconfig \
	sound/pci/Kconfig \
	sound/hda/Kconfig \
	sound/hda/common/Kconfig \
	sound/hda/controllers/Kconfig \
	sound/hda/codecs/Kconfig \
	sound/hda/codecs/realtek/Kconfig \
	sound/hda/codecs/cirrus/Kconfig \
	sound/hda/codecs/hdmi/Kconfig \
	sound/hda/codecs/side-codecs/Kconfig \
	sound/hda/core/Kconfig \
	sound/ppc/Kconfig \
	sound/ac97/Kconfig \
	sound/aoa/Kconfig \
	sound/aoa/fabrics/Kconfig \
	sound/aoa/codecs/Kconfig \
	sound/aoa/soundbus/Kconfig \
	sound/arm/Kconfig \
	sound/atmel/Kconfig \
	sound/spi/Kconfig \
	sound/mips/Kconfig \
	sound/sh/Kconfig \
	sound/usb/Kconfig \
	sound/usb/line6/Kconfig \
	sound/firewire/Kconfig \
	sound/pcmcia/Kconfig \
	sound/sparc/Kconfig \
	sound/parisc/Kconfig \
	sound/soc/Kconfig \
	sound/soc/adi/Kconfig \
	sound/soc/amd/Kconfig \
	sound/soc/amd/acp/Kconfig \
	sound/soc/apple/Kconfig \
	sound/soc/atmel/Kconfig \
	sound/soc/au1x/Kconfig \
	sound/soc/bcm/Kconfig \
	sound/soc/cirrus/Kconfig \
	sound/soc/dwc/Kconfig \
	sound/soc/fsl/Kconfig \
	sound/soc/google/Kconfig \
	sound/soc/hisilicon/Kconfig \
	sound/soc/jz4740/Kconfig \
	sound/soc/kirkwood/Kconfig \
	sound/soc/loongson/Kconfig \
	sound/soc/img/Kconfig \
	sound/soc/intel/Kconfig \
	sound/soc/intel/avs/boards/Kconfig \
	sound/soc/intel/boards/Kconfig \
	sound/soc/mediatek/Kconfig \
	sound/soc/meson/Kconfig \
	sound/soc/mxs/Kconfig \
	sound/soc/pxa/Kconfig \
	sound/soc/qcom/Kconfig \
	sound/soc/renesas/Kconfig \
	sound/soc/rockchip/Kconfig \
	sound/soc/samsung/Kconfig \
	sound/soc/sdca/Kconfig \
	sound/soc/sophgo/Kconfig \
	sound/soc/spacemit/Kconfig \
	sound/soc/spear/Kconfig \
	sound/soc/sprd/Kconfig \
	sound/soc/starfive/Kconfig \
	sound/soc/sti/Kconfig \
	sound/soc/stm/Kconfig \
	sound/soc/sunxi/Kconfig \
	sound/soc/tegra/Kconfig \
	sound/soc/ti/Kconfig \
	sound/soc/uniphier/Kconfig \
	sound/soc/ux500/Kconfig \
	sound/soc/xilinx/Kconfig \
	sound/soc/xtensa/Kconfig \
	sound/soc/sof/Kconfig \
	sound/soc/sof/amd/Kconfig \
	sound/soc/sof/imx/Kconfig \
	sound/soc/sof/intel/Kconfig \
	sound/soc/sof/mediatek/Kconfig \
	sound/soc/sof/xtensa/Kconfig \
	sound/soc/codecs/Kconfig \
	sound/soc/sdw_utils/Kconfig \
	sound/soc/generic/Kconfig \
	sound/x86/Kconfig \
	sound/synth/Kconfig \
	sound/xen/Kconfig \
	sound/virtio/Kconfig \
	drivers/hid/Kconfig \
	drivers/hid/bpf/Kconfig \
	drivers/hid/i2c-hid/Kconfig \
	drivers/hid/intel-ish-hid/Kconfig \
	drivers/hid/amd-sfh-hid/Kconfig \
	drivers/hid/surface-hid/Kconfig \
	drivers/hid/intel-thc-hid/Kconfig \
	drivers/hid/usbhid/Kconfig \
	drivers/usb/Kconfig \
	drivers/usb/common/Kconfig \
	drivers/usb/core/Kconfig \
	drivers/usb/mon/Kconfig \
	drivers/usb/host/Kconfig \
	drivers/usb/renesas_usbhs/Kconfig \
	drivers/usb/class/Kconfig \
	drivers/usb/storage/Kconfig \
	drivers/usb/image/Kconfig \
	drivers/usb/usbip/Kconfig \
	drivers/usb/cdns3/Kconfig \
	drivers/usb/fotg210/Kconfig \
	drivers/usb/mtu3/Kconfig \
	drivers/usb/musb/Kconfig \
	drivers/usb/dwc3/Kconfig \
	drivers/usb/dwc2/Kconfig \
	drivers/usb/chipidea/Kconfig \
	drivers/usb/isp1760/Kconfig \
	drivers/usb/serial/Kconfig \
	drivers/usb/misc/Kconfig \
	drivers/usb/misc/sisusbvga/Kconfig \
	drivers/usb/atm/Kconfig \
	drivers/usb/phy/Kconfig \
	drivers/usb/gadget/Kconfig \
	drivers/usb/gadget/udc/Kconfig \
	drivers/usb/gadget/udc/bdc/Kconfig \
	drivers/usb/gadget/udc/aspeed-vhub/Kconfig \
	drivers/usb/gadget/udc/cdns2/Kconfig \
	drivers/usb/gadget/legacy/Kconfig \
	drivers/usb/typec/Kconfig \
	drivers/usb/typec/tcpm/Kconfig \
	drivers/usb/typec/ucsi/Kconfig \
	drivers/usb/typec/tipd/Kconfig \
	drivers/usb/typec/mux/Kconfig \
	drivers/usb/typec/altmodes/Kconfig \
	drivers/usb/roles/Kconfig \
	drivers/mmc/Kconfig \
	drivers/mmc/core/Kconfig \
	drivers/mmc/host/Kconfig \
	drivers/ufs/Kconfig \
	drivers/ufs/core/Kconfig \
	drivers/ufs/host/Kconfig \
	drivers/memstick/Kconfig \
	drivers/memstick/core/Kconfig \
	drivers/memstick/host/Kconfig \
	drivers/leds/Kconfig \
	drivers/leds/blink/Kconfig \
	drivers/leds/flash/Kconfig \
	drivers/leds/rgb/Kconfig \
	drivers/leds/trigger/Kconfig \
	drivers/leds/simatic/Kconfig \
	drivers/accessibility/Kconfig \
	drivers/accessibility/speakup/Kconfig \
	drivers/infiniband/Kconfig \
	drivers/infiniband/hw/bnxt_re/Kconfig \
	drivers/infiniband/hw/bng_re/Kconfig \
	drivers/infiniband/hw/cxgb4/Kconfig \
	drivers/infiniband/hw/efa/Kconfig \
	drivers/infiniband/hw/erdma/Kconfig \
	drivers/infiniband/hw/hfi1/Kconfig \
	drivers/infiniband/hw/hns/Kconfig \
	drivers/infiniband/hw/ionic/Kconfig \
	drivers/infiniband/hw/irdma/Kconfig \
	drivers/infiniband/hw/mana/Kconfig \
	drivers/infiniband/hw/mlx4/Kconfig \
	drivers/infiniband/hw/mlx5/Kconfig \
	drivers/infiniband/hw/mthca/Kconfig \
	drivers/infiniband/hw/ocrdma/Kconfig \
	drivers/infiniband/hw/qedr/Kconfig \
	drivers/infiniband/hw/usnic/Kconfig \
	drivers/infiniband/hw/vmw_pvrdma/Kconfig \
	drivers/infiniband/sw/rdmavt/Kconfig \
	drivers/infiniband/sw/rxe/Kconfig \
	drivers/infiniband/sw/siw/Kconfig \
	drivers/infiniband/ulp/ipoib/Kconfig \
	drivers/infiniband/ulp/srp/Kconfig \
	drivers/infiniband/ulp/srpt/Kconfig \
	drivers/infiniband/ulp/iser/Kconfig \
	drivers/infiniband/ulp/isert/Kconfig \
	drivers/infiniband/ulp/rtrs/Kconfig \
	drivers/infiniband/ulp/opa_vnic/Kconfig \
	drivers/edac/Kconfig \
	drivers/rtc/Kconfig \
	drivers/dma/Kconfig \
	drivers/dma/amd/Kconfig \
	drivers/dma/bestcomm/Kconfig \
	drivers/dma/mediatek/Kconfig \
	drivers/dma/qcom/Kconfig \
	drivers/dma/dw/Kconfig \
	drivers/dma/dw-edma/Kconfig \
	drivers/dma/hsu/Kconfig \
	drivers/dma/sf-pdma/Kconfig \
	drivers/dma/sh/Kconfig \
	drivers/dma/ti/Kconfig \
	drivers/dma/fsl-dpaa2-qdma/Kconfig \
	drivers/dma/lgm/Kconfig \
	drivers/dma/stm32/Kconfig \
	drivers/dma-buf/Kconfig \
	drivers/dma-buf/heaps/Kconfig \
	drivers/dca/Kconfig \
	drivers/uio/Kconfig \
	drivers/vfio/Kconfig \
	drivers/vfio/pci/Kconfig \
	drivers/vfio/pci/mlx5/Kconfig \
	drivers/vfio/pci/hisilicon/Kconfig \
	drivers/vfio/pci/pds/Kconfig \
	drivers/vfio/pci/virtio/Kconfig \
	drivers/vfio/pci/nvgrace-gpu/Kconfig \
	drivers/vfio/pci/qat/Kconfig \
	drivers/vfio/pci/xe/Kconfig \
	drivers/vfio/platform/Kconfig \
	drivers/vfio/platform/reset/Kconfig \
	drivers/vfio/mdev/Kconfig \
	drivers/vfio/fsl-mc/Kconfig \
	drivers/vfio/cdx/Kconfig \
	virt/lib/Kconfig \
	drivers/virt/Kconfig \
	drivers/virt/vboxguest/Kconfig \
	drivers/virt/nitro_enclaves/Kconfig \
	drivers/virt/acrn/Kconfig \
	drivers/virt/coco/Kconfig \
	drivers/virt/coco/efi_secret/Kconfig \
	drivers/virt/coco/pkvm-guest/Kconfig \
	drivers/virt/coco/sev-guest/Kconfig \
	drivers/virt/coco/tdx-guest/Kconfig \
	drivers/virt/coco/arm-cca-guest/Kconfig \
	drivers/virt/coco/guest/Kconfig \
	drivers/virtio/Kconfig \
	drivers/vdpa/Kconfig \
	drivers/vhost/Kconfig \
	drivers/hv/Kconfig \
	drivers/xen/Kconfig \
	drivers/greybus/Kconfig \
	drivers/comedi/Kconfig \
	drivers/gpib/Kconfig \
	drivers/staging/Kconfig \
	drivers/staging/rtl8723bs/Kconfig \
	drivers/staging/octeon/Kconfig \
	drivers/staging/iio/Kconfig \
	drivers/staging/iio/accel/Kconfig \
	drivers/staging/iio/adc/Kconfig \
	drivers/staging/iio/addac/Kconfig \
	drivers/staging/iio/frequency/Kconfig \
	drivers/staging/iio/impedance-analyzer/Kconfig \
	drivers/staging/sm750fb/Kconfig \
	drivers/staging/nvec/Kconfig \
	drivers/staging/media/Kconfig \
	drivers/staging/media/atomisp/Kconfig \
	drivers/staging/media/atomisp/i2c/Kconfig \
	drivers/staging/media/av7110/Kconfig \
	drivers/staging/media/imx/Kconfig \
	drivers/staging/media/ipu3/Kconfig \
	drivers/staging/media/ipu7/Kconfig \
	drivers/staging/media/max96712/Kconfig \
	drivers/staging/media/meson/vdec/Kconfig \
	drivers/staging/media/starfive/Kconfig \
	drivers/staging/media/starfive/camss/Kconfig \
	drivers/staging/media/sunxi/Kconfig \
	drivers/staging/media/sunxi/cedrus/Kconfig \
	drivers/staging/media/sunxi/sun6i-isp/Kconfig \
	drivers/staging/media/tegra-video/Kconfig \
	drivers/staging/media/deprecated/atmel/Kconfig \
	drivers/staging/fbtft/Kconfig \
	drivers/staging/most/Kconfig \
	drivers/staging/most/net/Kconfig \
	drivers/staging/most/video/Kconfig \
	drivers/staging/most/dim2/Kconfig \
	drivers/staging/greybus/Kconfig \
	drivers/staging/vc04_services/Kconfig \
	drivers/staging/vc04_services/bcm2835-audio/Kconfig \
	drivers/staging/axis-fifo/Kconfig \
	drivers/staging/vme_user/Kconfig \
	drivers/platform/Kconfig \
	drivers/platform/mips/Kconfig \
	drivers/platform/loongarch/Kconfig \
	drivers/platform/goldfish/Kconfig \
	drivers/platform/chrome/Kconfig \
	drivers/platform/chrome/wilco_ec/Kconfig \
	drivers/platform/cznic/Kconfig \
	drivers/platform/mellanox/Kconfig \
	drivers/platform/olpc/Kconfig \
	drivers/platform/surface/Kconfig \
	drivers/platform/surface/aggregator/Kconfig \
	drivers/platform/x86/Kconfig \
	drivers/platform/x86/uniwill/Kconfig \
	drivers/platform/x86/amd/Kconfig \
	drivers/platform/x86/amd/hsmp/Kconfig \
	drivers/platform/x86/amd/pmf/Kconfig \
	drivers/platform/x86/amd/pmc/Kconfig \
	drivers/platform/x86/amd/hfi/Kconfig \
	drivers/platform/x86/dell/Kconfig \
	drivers/platform/x86/hp/Kconfig \
	drivers/platform/x86/intel/Kconfig \
	drivers/platform/x86/intel/atomisp2/Kconfig \
	drivers/platform/x86/intel/ifs/Kconfig \
	drivers/platform/x86/intel/int1092/Kconfig \
	drivers/platform/x86/intel/int3472/Kconfig \
	drivers/platform/x86/intel/pmc/Kconfig \
	drivers/platform/x86/intel/pmt/Kconfig \
	drivers/platform/x86/intel/speed_select_if/Kconfig \
	drivers/platform/x86/intel/telemetry/Kconfig \
	drivers/platform/x86/intel/wmi/Kconfig \
	drivers/platform/x86/intel/uncore-frequency/Kconfig \
	drivers/platform/x86/lenovo/Kconfig \
	drivers/platform/x86/x86-android-tablets/Kconfig \
	drivers/platform/x86/siemens/Kconfig \
	drivers/platform/x86/tuxedo/Kconfig \
	drivers/platform/x86/tuxedo/nb04/Kconfig \
	drivers/platform/arm64/Kconfig \
	drivers/platform/raspberrypi/Kconfig \
	drivers/platform/raspberrypi/vchiq-mmal/Kconfig \
	drivers/platform/wmi/Kconfig \
	drivers/platform/wmi/tests/Kconfig \
	drivers/clk/Kconfig \
	drivers/clk/versatile/Kconfig \
	drivers/clk/actions/Kconfig \
	drivers/clk/analogbits/Kconfig \
	drivers/clk/aspeed/Kconfig \
	drivers/clk/baikal-t1/Kconfig \
	drivers/clk/bcm/Kconfig \
	drivers/clk/hisilicon/Kconfig \
	drivers/clk/imgtec/Kconfig \
	drivers/clk/imx/Kconfig \
	drivers/clk/ingenic/Kconfig \
	drivers/clk/keystone/Kconfig \
	drivers/clk/mediatek/Kconfig \
	drivers/clk/mmp/Kconfig \
	drivers/clk/meson/Kconfig \
	drivers/clk/mstar/Kconfig \
	drivers/clk/microchip/Kconfig \
	drivers/clk/mvebu/Kconfig \
	drivers/clk/nuvoton/Kconfig \
	drivers/clk/pistachio/Kconfig \
	drivers/clk/qcom/Kconfig \
	drivers/clk/ralink/Kconfig \
	drivers/clk/renesas/Kconfig \
	drivers/clk/rockchip/Kconfig \
	drivers/clk/samsung/Kconfig \
	drivers/clk/sifive/Kconfig \
	drivers/clk/socfpga/Kconfig \
	drivers/clk/sophgo/Kconfig \
	drivers/clk/spacemit/Kconfig \
	drivers/clk/sprd/Kconfig \
	drivers/clk/starfive/Kconfig \
	drivers/clk/sunxi/Kconfig \
	drivers/clk/sunxi-ng/Kconfig \
	drivers/clk/tegra/Kconfig \
	drivers/clk/thead/Kconfig \
	drivers/clk/stm32/Kconfig \
	drivers/clk/ti/Kconfig \
	drivers/clk/uniphier/Kconfig \
	drivers/clk/visconti/Kconfig \
	drivers/clk/x86/Kconfig \
	drivers/clk/xilinx/Kconfig \
	drivers/clk/zynqmp/Kconfig \
	drivers/hwspinlock/Kconfig \
	drivers/clocksource/Kconfig \
	drivers/mailbox/Kconfig \
	drivers/iommu/Kconfig \
	drivers/iommu/amd/Kconfig \
	drivers/iommu/arm/Kconfig \
	drivers/iommu/intel/Kconfig \
	drivers/iommu/iommufd/Kconfig \
	drivers/iommu/riscv/Kconfig \
	drivers/iommu/generic_pt/Kconfig \
	drivers/remoteproc/Kconfig \
	drivers/rpmsg/Kconfig \
	drivers/soundwire/Kconfig \
	drivers/soc/Kconfig \
	drivers/soc/amlogic/Kconfig \
	drivers/soc/apple/Kconfig \
	drivers/soc/aspeed/Kconfig \
	drivers/soc/atmel/Kconfig \
	drivers/soc/bcm/Kconfig \
	drivers/soc/bcm/brcmstb/Kconfig \
	drivers/soc/canaan/Kconfig \
	drivers/soc/cirrus/Kconfig \
	drivers/soc/fsl/Kconfig \
	drivers/soc/fsl/qbman/Kconfig \
	drivers/soc/fsl/qe/Kconfig \
	drivers/soc/fujitsu/Kconfig \
	drivers/soc/hisilicon/Kconfig \
	drivers/soc/imx/Kconfig \
	drivers/soc/ixp4xx/Kconfig \
	drivers/soc/litex/Kconfig \
	drivers/soc/loongson/Kconfig \
	drivers/soc/mediatek/Kconfig \
	drivers/soc/microchip/Kconfig \
	drivers/soc/nuvoton/Kconfig \
	drivers/soc/pxa/Kconfig \
	drivers/soc/qcom/Kconfig \
	drivers/soc/renesas/Kconfig \
	drivers/soc/rockchip/Kconfig \
	drivers/soc/samsung/Kconfig \
	drivers/soc/sophgo/Kconfig \
	drivers/soc/sunxi/Kconfig \
	drivers/soc/tegra/Kconfig \
	drivers/soc/ti/Kconfig \
	drivers/soc/ux500/Kconfig \
	drivers/soc/versatile/Kconfig \
	drivers/soc/vt8500/Kconfig \
	drivers/soc/xilinx/Kconfig \
	drivers/pmdomain/Kconfig \
	drivers/pmdomain/actions/Kconfig \
	drivers/pmdomain/amlogic/Kconfig \
	drivers/pmdomain/apple/Kconfig \
	drivers/pmdomain/arm/Kconfig \
	drivers/pmdomain/bcm/Kconfig \
	drivers/pmdomain/imx/Kconfig \
	drivers/pmdomain/marvell/Kconfig \
	drivers/pmdomain/mediatek/Kconfig \
	drivers/pmdomain/qcom/Kconfig \
	drivers/pmdomain/renesas/Kconfig \
	drivers/pmdomain/rockchip/Kconfig \
	drivers/pmdomain/samsung/Kconfig \
	drivers/pmdomain/st/Kconfig \
	drivers/pmdomain/starfive/Kconfig \
	drivers/pmdomain/sunxi/Kconfig \
	drivers/pmdomain/tegra/Kconfig \
	drivers/pmdomain/thead/Kconfig \
	drivers/pmdomain/ti/Kconfig \
	drivers/pmdomain/xilinx/Kconfig \
	drivers/devfreq/Kconfig \
	drivers/devfreq/event/Kconfig \
	drivers/extcon/Kconfig \
	drivers/memory/Kconfig \
	drivers/memory/samsung/Kconfig \
	drivers/memory/tegra/Kconfig \
	drivers/iio/Kconfig \
	drivers/iio/buffer/Kconfig \
	drivers/iio/accel/Kconfig \
	drivers/iio/adc/Kconfig \
	drivers/iio/addac/Kconfig \
	drivers/iio/afe/Kconfig \
	drivers/iio/amplifiers/Kconfig \
	drivers/iio/cdc/Kconfig \
	drivers/iio/chemical/Kconfig \
	drivers/iio/common/Kconfig \
	drivers/iio/common/cros_ec_sensors/Kconfig \
	drivers/iio/common/hid-sensors/Kconfig \
	drivers/iio/common/inv_sensors/Kconfig \
	drivers/iio/common/ms_sensors/Kconfig \
	drivers/iio/common/scmi_sensors/Kconfig \
	drivers/iio/common/ssp_sensors/Kconfig \
	drivers/iio/common/st_sensors/Kconfig \
	drivers/iio/dac/Kconfig \
	drivers/iio/dummy/Kconfig \
	drivers/iio/filter/Kconfig \
	drivers/iio/frequency/Kconfig \
	drivers/iio/gyro/Kconfig \
	drivers/iio/health/Kconfig \
	drivers/iio/humidity/Kconfig \
	drivers/iio/imu/Kconfig \
	drivers/iio/imu/bmi160/Kconfig \
	drivers/iio/imu/bmi270/Kconfig \
	drivers/iio/imu/bmi323/Kconfig \
	drivers/iio/imu/bno055/Kconfig \
	drivers/iio/imu/inv_icm42600/Kconfig \
	drivers/iio/imu/inv_icm45600/Kconfig \
	drivers/iio/imu/inv_mpu6050/Kconfig \
	drivers/iio/imu/smi330/Kconfig \
	drivers/iio/imu/st_lsm6dsx/Kconfig \
	drivers/iio/imu/st_lsm9ds0/Kconfig \
	drivers/iio/light/Kconfig \
	drivers/iio/magnetometer/Kconfig \
	drivers/iio/multiplexer/Kconfig \
	drivers/iio/orientation/Kconfig \
	drivers/iio/test/Kconfig \
	drivers/iio/trigger/Kconfig \
	drivers/iio/position/Kconfig \
	drivers/iio/potentiometer/Kconfig \
	drivers/iio/potentiostat/Kconfig \
	drivers/iio/pressure/Kconfig \
	drivers/iio/proximity/Kconfig \
	drivers/iio/resolver/Kconfig \
	drivers/iio/temperature/Kconfig \
	drivers/ntb/Kconfig \
	drivers/ntb/hw/Kconfig \
	drivers/ntb/hw/amd/Kconfig \
	drivers/ntb/hw/idt/Kconfig \
	drivers/ntb/hw/intel/Kconfig \
	drivers/ntb/hw/epf/Kconfig \
	drivers/ntb/hw/mscc/Kconfig \
	drivers/ntb/test/Kconfig \
	drivers/pwm/Kconfig \
	drivers/irqchip/Kconfig \
	drivers/ipack/Kconfig \
	drivers/ipack/carriers/Kconfig \
	drivers/ipack/devices/Kconfig \
	drivers/reset/Kconfig \
	drivers/reset/amlogic/Kconfig \
	drivers/reset/hisilicon/Kconfig \
	drivers/reset/spacemit/Kconfig \
	drivers/reset/starfive/Kconfig \
	drivers/reset/sti/Kconfig \
	drivers/reset/tegra/Kconfig \
	drivers/phy/Kconfig \
	drivers/phy/allwinner/Kconfig \
	drivers/phy/amlogic/Kconfig \
	drivers/phy/apple/Kconfig \
	drivers/phy/broadcom/Kconfig \
	drivers/phy/cadence/Kconfig \
	drivers/phy/freescale/Kconfig \
	drivers/phy/hisilicon/Kconfig \
	drivers/phy/ingenic/Kconfig \
	drivers/phy/lantiq/Kconfig \
	drivers/phy/marvell/Kconfig \
	drivers/phy/mediatek/Kconfig \
	drivers/phy/microchip/Kconfig \
	drivers/phy/motorola/Kconfig \
	drivers/phy/mscc/Kconfig \
	drivers/phy/nuvoton/Kconfig \
	drivers/phy/qualcomm/Kconfig \
	drivers/phy/ralink/Kconfig \
	drivers/phy/realtek/Kconfig \
	drivers/phy/renesas/Kconfig \
	drivers/phy/rockchip/Kconfig \
	drivers/phy/samsung/Kconfig \
	drivers/phy/socionext/Kconfig \
	drivers/phy/sophgo/Kconfig \
	drivers/phy/spacemit/Kconfig \
	drivers/phy/st/Kconfig \
	drivers/phy/starfive/Kconfig \
	drivers/phy/sunplus/Kconfig \
	drivers/phy/tegra/Kconfig \
	drivers/phy/ti/Kconfig \
	drivers/phy/intel/Kconfig \
	drivers/phy/xilinx/Kconfig \
	drivers/powercap/Kconfig \
	drivers/mcb/Kconfig \
	drivers/perf/Kconfig \
	drivers/perf/hisilicon/Kconfig \
	drivers/perf/arm_cspmu/Kconfig \
	drivers/perf/amlogic/Kconfig \
	drivers/ras/Kconfig \
	arch/x86/ras/Kconfig \
	drivers/ras/amd/atl/Kconfig \
	drivers/thunderbolt/Kconfig \
	drivers/android/Kconfig \
	drivers/nvdimm/Kconfig \
	drivers/dax/Kconfig \
	drivers/nvmem/Kconfig \
	drivers/nvmem/layouts/Kconfig \
	drivers/hwtracing/Kconfig \
	drivers/hwtracing/stm/Kconfig \
	drivers/hwtracing/intel_th/Kconfig \
	drivers/hwtracing/ptt/Kconfig \
	drivers/fpga/Kconfig \
	drivers/fpga/tests/Kconfig \
	drivers/fsi/Kconfig \
	drivers/tee/Kconfig \
	drivers/tee/optee/Kconfig \
	drivers/tee/amdtee/Kconfig \
	drivers/tee/tstee/Kconfig \
	drivers/tee/qcomtee/Kconfig \
	drivers/mux/Kconfig \
	drivers/opp/Kconfig \
	drivers/siox/Kconfig \
	drivers/slimbus/Kconfig \
	drivers/interconnect/Kconfig \
	drivers/interconnect/imx/Kconfig \
	drivers/interconnect/mediatek/Kconfig \
	drivers/interconnect/qcom/Kconfig \
	drivers/interconnect/samsung/Kconfig \
	drivers/counter/Kconfig \
	drivers/most/Kconfig \
	drivers/peci/Kconfig \
	drivers/peci/controller/Kconfig \
	drivers/hte/Kconfig \
	drivers/cdx/Kconfig \
	drivers/cdx/controller/Kconfig \
	drivers/resctrl/Kconfig \
	fs/Kconfig \
	fs/ext2/Kconfig \
	fs/ext4/Kconfig \
	fs/jbd2/Kconfig \
	fs/jfs/Kconfig \
	fs/xfs/Kconfig \
	fs/gfs2/Kconfig \
	fs/ocfs2/Kconfig \
	fs/btrfs/Kconfig \
	fs/nilfs2/Kconfig \
	fs/f2fs/Kconfig \
	fs/zonefs/Kconfig \
	fs/crypto/Kconfig \
	fs/verity/Kconfig \
	fs/notify/Kconfig \
	fs/notify/dnotify/Kconfig \
	fs/notify/inotify/Kconfig \
	fs/notify/fanotify/Kconfig \
	fs/quota/Kconfig \
	fs/autofs/Kconfig \
	fs/fuse/Kconfig \
	fs/overlayfs/Kconfig \
	fs/netfs/Kconfig \
	fs/cachefiles/Kconfig \
	fs/isofs/Kconfig \
	fs/udf/Kconfig \
	fs/fat/Kconfig \
	fs/exfat/Kconfig \
	fs/ntfs3/Kconfig \
	fs/proc/Kconfig \
	fs/kernfs/Kconfig \
	fs/sysfs/Kconfig \
	fs/configfs/Kconfig \
	fs/efivarfs/Kconfig \
	fs/orangefs/Kconfig \
	fs/adfs/Kconfig \
	fs/affs/Kconfig \
	fs/ecryptfs/Kconfig \
	fs/hfs/Kconfig \
	fs/hfsplus/Kconfig \
	fs/befs/Kconfig \
	fs/bfs/Kconfig \
	fs/efs/Kconfig \
	fs/jffs2/Kconfig \
	fs/ubifs/Kconfig \
	fs/cramfs/Kconfig \
	fs/squashfs/Kconfig \
	fs/freevxfs/Kconfig \
	fs/minix/Kconfig \
	fs/omfs/Kconfig \
	fs/hpfs/Kconfig \
	fs/qnx4/Kconfig \
	fs/qnx6/Kconfig \
	fs/resctrl/Kconfig \
	fs/romfs/Kconfig \
	fs/pstore/Kconfig \
	fs/ufs/Kconfig \
	fs/erofs/Kconfig \
	fs/vboxsf/Kconfig \
	fs/nfs/Kconfig \
	fs/nfsd/Kconfig \
	net/sunrpc/Kconfig \
	fs/ceph/Kconfig \
	fs/smb/Kconfig \
	fs/smb/client/Kconfig \
	fs/smb/server/Kconfig \
	fs/coda/Kconfig \
	fs/afs/Kconfig \
	fs/9p/Kconfig \
	fs/nls/Kconfig \
	fs/dlm/Kconfig \
	fs/unicode/Kconfig \
	security/Kconfig \
	security/keys/Kconfig \
	security/keys/trusted-keys/Kconfig \
	security/selinux/Kconfig \
	security/smack/Kconfig \
	security/tomoyo/Kconfig \
	security/apparmor/Kconfig \
	security/loadpin/Kconfig \
	security/yama/Kconfig \
	security/safesetid/Kconfig \
	security/lockdown/Kconfig \
	security/landlock/Kconfig \
	security/ipe/Kconfig \
	security/integrity/Kconfig \
	security/integrity/ima/Kconfig \
	security/integrity/evm/Kconfig \
	security/Kconfig.hardening \
	crypto/Kconfig \
	crypto/async_tx/Kconfig \
	arch/arm/crypto/Kconfig \
	arch/arm64/crypto/Kconfig \
	arch/loongarch/crypto/Kconfig \
	arch/mips/crypto/Kconfig \
	arch/powerpc/crypto/Kconfig \
	arch/riscv/crypto/Kconfig \
	arch/s390/crypto/Kconfig \
	arch/sparc/crypto/Kconfig \
	arch/x86/crypto/Kconfig \
	drivers/crypto/Kconfig \
	drivers/crypto/allwinner/Kconfig \
	drivers/crypto/caam/Kconfig \
	drivers/crypto/nx/Kconfig \
	drivers/crypto/ccp/Kconfig \
	drivers/crypto/cavium/cpt/Kconfig \
	drivers/crypto/cavium/nitrox/Kconfig \
	drivers/crypto/marvell/Kconfig \
	drivers/crypto/intel/Kconfig \
	drivers/crypto/intel/keembay/Kconfig \
	drivers/crypto/intel/ixp4xx/Kconfig \
	drivers/crypto/intel/qat/Kconfig \
	drivers/crypto/intel/iaa/Kconfig \
	drivers/crypto/chelsio/Kconfig \
	drivers/crypto/virtio/Kconfig \
	drivers/crypto/stm32/Kconfig \
	drivers/crypto/hisilicon/Kconfig \
	drivers/crypto/loongson/Kconfig \
	drivers/crypto/amlogic/Kconfig \
	drivers/crypto/aspeed/Kconfig \
	drivers/crypto/starfive/Kconfig \
	drivers/crypto/inside-secure/eip93/Kconfig \
	drivers/crypto/ti/Kconfig \
	crypto/asymmetric_keys/Kconfig \
	certs/Kconfig \
	crypto/krb5/Kconfig \
	lib/Kconfig \
	lib/math/Kconfig \
	lib/crc/Kconfig \
	lib/crypto/Kconfig \
	lib/crypto/tests/Kconfig \
	lib/xz/Kconfig \
	kernel/dma/Kconfig \
	lib/vdso/Kconfig \
	lib/fonts/Kconfig \
	lib/Kconfig.debug \
	lib/Kconfig.kgdb \
	lib/Kconfig.ubsan \
	lib/Kconfig.kcsan \
	net/Kconfig.debug \
	mm/Kconfig.debug \
	lib/Kconfig.kasan \
	lib/Kconfig.kfence \
	lib/Kconfig.kmsan \
	kernel/rcu/Kconfig.debug \
	kernel/trace/Kconfig \
	kernel/trace/rv/Kconfig \
	kernel/trace/rv/monitors/wip/Kconfig \
	kernel/trace/rv/monitors/wwnr/Kconfig \
	kernel/trace/rv/monitors/sched/Kconfig \
	kernel/trace/rv/monitors/sco/Kconfig \
	kernel/trace/rv/monitors/snroc/Kconfig \
	kernel/trace/rv/monitors/scpd/Kconfig \
	kernel/trace/rv/monitors/snep/Kconfig \
	kernel/trace/rv/monitors/sts/Kconfig \
	kernel/trace/rv/monitors/nrp/Kconfig \
	kernel/trace/rv/monitors/sssw/Kconfig \
	kernel/trace/rv/monitors/opid/Kconfig \
	kernel/trace/rv/monitors/rtapp/Kconfig \
	kernel/trace/rv/monitors/pagefault/Kconfig \
	kernel/trace/rv/monitors/sleep/Kconfig \
	samples/Kconfig \
	samples/rust/Kconfig \
	samples/damon/Kconfig \
	arch/x86/Kconfig.debug \
	lib/kunit/Kconfig \
	Documentation/Kconfig \
	io_uring/Kconfig \

$(autoconfig): $(deps_config)
$(deps_config): ;

ifneq "$(ARCH)" "x86"
$(autoconfig): FORCE
endif

ifneq "$(KERNELVERSION)" "7.0.9-rt2-arch2"
$(autoconfig): FORCE
endif

ifneq "$(CC)" "gcc"
$(autoconfig): FORCE
endif

ifneq "$(LD)" "ld"
$(autoconfig): FORCE
endif

ifneq "$(srctree)" "."
$(autoconfig): FORCE
endif

ifneq "$(RUSTC)" "rustc"
$(autoconfig): FORCE
endif

ifneq "$(CC_VERSION_TEXT)" "gcc (GCC) 16.1.1 20260430"
$(autoconfig): FORCE
endif

ifneq "$(NM)" "nm"
$(autoconfig): FORCE
endif

ifneq "$(OBJCOPY)" "objcopy"
$(autoconfig): FORCE
endif

ifneq "$(PAHOLE_VERSION)" "131"
$(autoconfig): FORCE
endif

ifneq "$(RUSTC_VERSION_TEXT)" "rustc 1.95.0 (59807616e 2026-04-14) (Arch Linux rust 1:1.95.0-1)"
$(autoconfig): FORCE
endif

ifneq "$(BINDGEN)" "bindgen"
$(autoconfig): FORCE
endif

ifneq "$(SRCARCH)" "x86"
$(autoconfig): FORCE
endif

ifneq "$(AR)" "ar"
$(autoconfig): FORCE
endif

ifneq "$(PYTHON3)" "python3"
$(autoconfig): FORCE
endif
